==> mingw-w64-precice-2.1.1-2.src.tar.gz: precice-2.1.1/docs/README.md <==
# preCICE #

**Communication**  
<a style="text-decoration: none" href="https://gitter.im/precice/Lobby" target="_blank">
    <img src="https://img.shields.io/badge/chat-on%20gitter-9c3375.svg" alt="Gitter chat">
</a>
<a style="text-decoration: none" href="https://precice.discourse.group" target="_blank">
    <img alt="Discourse posts" src="https://img.shields.io/discourse/posts?label=discourse%20QA&server=https%3A%2F%2Fprecice.discourse.group">
</a>
<a style="text-decoration: none" href="https://mailman.informatik.uni-stuttgart.de/mailman/listinfo/precice" target="_blank">
    <img src="https://img.shields.io/badge/mailing%20list-subscribe-blue.svg" alt="Mailing list">
</a>
<a style="text-decoration: none" href="https://twitter.com/preCICE_org" target="_blank">
    <img src="https://img.shields.io/badge/twitter-%40preCICE__org-1da1f2.svg" alt="Twitter">
</a>
<a style="text-decoration: none" href="https://www.precice.org/" target="_blank">
    <img src="https://img.shields.io/website-up-down-green-red/https/www.precice.org.svg?label=website" alt="preCICE website status">
</a>

**Project Status**  
<a style="text-decoration: none" href="https://github.com/precice/precice/releases/latest" target="_blank">
    <img src="https://img.shields.io/github/release/precice/precice.svg" alt="Release">
</a>
<a style="text-decoration: none" href="https://travis-ci.org/precice/precice" target="_blank">
    <img src="https://travis-ci.org/precice/precice.svg?branch=develop" alt="Build status">
</a>
<a style="text-decoration: none" href="https://travis-ci.org/github/precice/systemtests/builds" target="_blank">
    <img src="https://img.shields.io/badge/system%20tests-check-blue" alt="Build status">
</a>

**Project Quality**  
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/3895/badge)](https://bestpractices.coreinfrastructure.org/projects/3895)
[![CodeFactor](https://www.codefactor.io/repository/github/precice/precice/badge)](https://www.codefactor.io/repository/github/precice/precice)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/498adf8b3dcb4543b828e443396eb66c)](https://www.codacy.com/app/fsimonis/precice?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=precice/precice&amp;utm_campaign=Badge_Grade)
[![Language grade: C/C++](https://img.shields.io/lgtm/grade/cpp/g/precice/precice.svg?logo=lgtm&logoWidth=18&label=lgtm%3AC%2B%2B)](https://lgtm.com/projects/g/precice/precice/context:cpp)
[![codecov](https://codecov.io/gh/precice/precice/branch/develop/graph/badge.svg)](https://codecov.io/gh/precice/precice)

preCICE stands for Precise Code Interaction Coupling Environment. Its main component is a library that can be used by simulation programs to be coupled together in a partitioned way, enabling multi-physics simulations, such as fluid-structure interaction.

If you are new to preCICE, please have a look at our [wiki (documentation)](https://github.com/precice/precice/wiki) and at [precice.org](https://www.precice.org). You may also prefer to [get and install a binary package for the latest release](https://github.com/precice/precice/releases/latest) ([master branch](https://github.com/precice/precice/tree/master)).

<div align="center" style="margin-bottom:30px">
<img src="https://www.precice.org/assets/precice_overview.png" alt="preCICE overview" style="max-height: 100%; max-width: 100%">
</div>

preCICE is an academic project, developed at the [Technical University of Munich](https://www5.in.tum.de/) and at the [University of Stuttgart](https://www.ipvs.uni-stuttgart.de/). If you use preCICE, please [cite us](https://www.precice.org/publications/):

*H.-J. Bungartz, F. Lindner, B. Gatzhammer, M. Mehl, K. Scheufele, A. Shukaev, and B. Uekermann: preCICE - A Fully Parallel Library for Multi-Physics Surface Coupling. Computers and Fluids, 141, 250–258, 2016.*

==> mingw-w64-precice-2.2.1-1.src.tar.gz: precice-2.2.1/docs/README.md <==
# preCICE #

**Communication**  
<a style="text-decoration: none" href="https://gitter.im/precice/Lobby" target="_blank">
    <img src="https://img.shields.io/badge/chat-on%20gitter-9c3375.svg" alt="Gitter chat">
</a>
<a style="text-decoration: none" href="https://precice.discourse.group" target="_blank">
    <img alt="Discourse posts" src="https://img.shields.io/discourse/posts?label=discourse%20QA&server=https%3A%2F%2Fprecice.discourse.group">
</a>
<a style="text-decoration: none" href="https://mailman.informatik.uni-stuttgart.de/mailman/listinfo/precice" target="_blank">
    <img src="https://img.shields.io/badge/mailing%20list-subscribe-blue.svg" alt="Mailing list">
</a>
<a style="text-decoration: none" href="https://twitter.com/preCICE_org" target="_blank">
    <img src="https://img.shields.io/badge/twitter-%40preCICE__org-1da1f2.svg" alt="Twitter">
</a>
<a style="text-decoration: none" href="https://www.precice.org/" target="_blank">
    <img src="https://img.shields.io/website-up-down-green-red/https/www.precice.org.svg?label=website" alt="preCICE website status">
</a>

**Project Status**  
<a style="text-decoration: none" href="https://github.com/precice/precice/releases/latest" target="_blank">
    <img src="https://img.shields.io/github/release/precice/precice.svg" alt="Release">
</a>
<a style="text-decoration: none" href="https://github.com/precice/precice/actions?query=workflow%3A%22Build+and+Test%22+branch%3Adevelop" target="_blank">
    <img src="https://github.com/precice/precice/workflows/Build%20and%20Test/badge.svg" alt="Build status">
</a>
<a style="text-decoration: none" href="https://travis-ci.org/github/precice/systemtests/builds" target="_blank">
    <img src="https://img.shields.io/badge/system%20tests-check-blue" alt="Build status">
</a>

**Project Quality**  
[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/3895/badge)](https://bestpractices.coreinfrastructure.org/projects/3895)
[![CodeFactor](https://www.codefactor.io/repository/github/precice/precice/badge)](https://www.codefactor.io/repository/github/precice/precice)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/498adf8b3dcb4543b828e443396eb66c)](https://www.codacy.com/app/fsimonis/precice?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=precice/precice&amp;utm_campaign=Badge_Grade)
[![Language grade: C/C++](https://img.shields.io/lgtm/grade/cpp/g/precice/precice.svg?logo=lgtm&logoWidth=18&label=lgtm%3AC%2B%2B)](https://lgtm.com/projects/g/precice/precice/context:cpp)
[![codecov](https://codecov.io/gh/precice/precice/branch/develop/graph/badge.svg)](https://codecov.io/gh/precice/precice)

preCICE stands for Precise Code Interaction Coupling Environment. Its main component is a library that can be used by simulation programs to be coupled together in a partitioned way, enabling multi-physics simulations, such as fluid-structure interaction.

If you are new to preCICE, please have a look at our [documentation](https://www.precice.org/docs.html) and at [precice.org](https://www.precice.org). You may also prefer to [get and install a binary package for the latest release](https://github.com/precice/precice/releases/latest) ([master branch](https://github.com/precice/precice/tree/master)).

<div align="center" style="margin-bottom:30px">
<img src="https://www.precice.org/material/overview/preCICE_overview.png" alt="preCICE overview" style="max-height: 100%; max-width: 100%">
</div>

preCICE is an academic project, developed at the [Technical University of Munich](https://www5.in.tum.de/) and at the [University of Stuttgart](https://www.ipvs.uni-stuttgart.de/). If you use preCICE, please [cite us](https://www.precice.org/publications/):

*H.-J. Bungartz, F. Lindner, B. Gatzhammer, M. Mehl, K. Scheufele, A. Shukaev, and B. Uekermann: preCICE - A Fully Parallel Library for Multi-Physics Surface Coupling. Computers and Fluids, 141, 250–258, 2016.*
